==> peony-extensions_4.0.0.0.orig.tar.gz: peony-extensions-4.0.0.0/peony-share/app/translations/peony-share-extension_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AdvancedSharePage</name>
    <message>
        <location filename="../advanced-share-page.cpp" line="58"/>
        <source>Advanced share</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="106"/>
        <source>Samba set user password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="106"/>
        <source>Samba password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="110"/>
        <location filename="../advanced-share-page.cpp" line="122"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="110"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="118"/>
        <source>Tips</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="118"/>
        <source>The user has not set the samba password. If you need to log in to %1, you can set it in the upper right menu of the file manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="122"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="263"/>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="263"/>
        <source>Writable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="263"/>
        <source>Readonly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="263"/>
        <source>Reject</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="358"/>
        <source>Share permission settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="370"/>
        <source>delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="387"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="404"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="405"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetUsershareHelper</name>
    <message>
        <source>Peony-Qt-Share-Extension</source>
        <translation type="vanished">Peony-Qt-Share-Extension</translation>
    </message>
</context>
<context>
    <name>Peony::SharePropertiesPagePlugin</name>
    <message>
        <location filename="../share-properties-page-plugin.h" line="44"/>
        <source>Peony Qt Share Extension</source>
        <translation>Rozšíření do Peony Qt pro správu sdílení</translation>
    </message>
    <message>
        <location filename="../share-properties-page-plugin.h" line="45"/>
        <source>Allow user share folders</source>
        <translation>Umožnit uživateli sdílet složku</translation>
    </message>
</context>
<context>
    <name>SharePage</name>
    <message>
        <location filename="../share-page.cpp" line="435"/>
        <source>Share folder</source>
        <translation>Sdílet složku</translation>
    </message>
    <message>
        <source>Share:</source>
        <translation type="vanished">Zdroj:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="130"/>
        <source>The folder is currently shared in non-read-only mode, and setting up the share requires adding other people&apos;s write permissions to the current folder?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="131"/>
        <location filename="../share-page.cpp" line="185"/>
        <source>question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="133"/>
        <location filename="../share-page.cpp" line="187"/>
        <source>Confirm adding permissions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="134"/>
        <location filename="../share-page.cpp" line="188"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="108"/>
        <location filename="../share-page.cpp" line="113"/>
        <location filename="../share-page.cpp" line="162"/>
        <location filename="../share-page.cpp" line="171"/>
        <location filename="../share-page.cpp" line="217"/>
        <location filename="../share-page.cpp" line="227"/>
        <location filename="../share-page.cpp" line="271"/>
        <location filename="../share-page.cpp" line="300"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="108"/>
        <source>The share name must not contain %1, and cannot start with a dash (-) or whitespace, or end with whitespace.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="113"/>
        <source>The share name cannot be the same as the current user name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="184"/>
        <source>The folder is currently shared with anonymous access set, do I need to automatically add executable permissions for the current file and all other members of the parent directory?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="271"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="280"/>
        <source>Samba set user password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="280"/>
        <source>Samba password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="300"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="402"/>
        <source>usershare</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="406"/>
        <location filename="../share-page.cpp" line="451"/>
        <source>share this folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="406"/>
        <location filename="../share-page.cpp" line="458"/>
        <source>don`t share this folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="486"/>
        <source>Share name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="491"/>
        <source>Allow others to create and delete files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="vanished">Pouze pro čtení</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="494"/>
        <source>Allow Anonymous</source>
        <translation>Umožnit anonymní</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="503"/>
        <source>Advanced Sharing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="487"/>
        <source>Comment:</source>
        <translation>Komentář:</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-share/app/translations/peony-share-extension_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>NetUsershareHelper</name>
    <message>
        <source>Peony-Qt-Share-Extension</source>
        <translation type="vanished">Peony-Qt-Share-Extension</translation>
    </message>
</context>
<context>
    <name>Peony::SharePropertiesPagePlugin</name>
    <message>
        <location filename="../share-properties-page-plugin.h" line="44"/>
        <source>Peony Qt Share Extension</source>
        <translation>Rozšíření do Peony Qt pro správu sdílení</translation>
    </message>
    <message>
        <location filename="../share-properties-page-plugin.h" line="45"/>
        <source>Allow user share folders</source>
        <translation>Umožnit uživateli sdílet složku</translation>
    </message>
</context>
<context>
    <name>SharePage</name>
    <message>
        <location filename="../share-page.cpp" line="169"/>
        <source>Share folder</source>
        <translation>Sdílet složku</translation>
    </message>
    <message>
        <source>Share:</source>
        <translation type="vanished">Zdroj:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="140"/>
        <source>usershare</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="144"/>
        <location filename="../share-page.cpp" line="187"/>
        <source>share this folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="144"/>
        <location filename="../share-page.cpp" line="194"/>
        <source>don`t share this folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="220"/>
        <source>Share name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="225"/>
        <source>Read Only</source>
        <translation>Pouze pro čtení</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="228"/>
        <source>Allow Anonymous</source>
        <translation>Umožnit anonymní</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="221"/>
        <source>Comment:</source>
        <translation>Komentář:</translation>
    </message>
</context>
</TS>
